==> emacspeak_26.0.orig.tar.gz: emacspeak-26.0.orig/lisp/flite-voices.el <==
;;; flite.el --- Emacspeak FLite
;;; $Id: flite-voices.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
;;; $Author: tv.raman.tv $
;;; Description:  FLite interface 
;;; Keywords: Emacspeak,  Audio Desktop FLite
;;{{{  LCD Archive entry:

;;; LCD Archive Entry:
;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
;;; A speech interface to Emacs |
;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
;;;  $Revision: 4532 $ |
;;; Location undetermined
;;;

;;}}}
;;{{{  Copyright:
;;;Copyright (C) 1995 -- 2007, T. V. Raman 
;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
;;; All Rights Reserved.
;;;
;;; This file is not part of GNU Emacs, but the same permissions apply.
;;;
;;; GNU Emacs is free software; you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 2, or (at your option)
;;; any later version.
;;;
;;; GNU Emacs is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with GNU Emacs; see the file COPYING.  If not, write to
;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

;;}}}
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;{{{  introduction

;;; defines interactive command tts-flite that launches eflite 
;;; this will be updated to use the FLite TCL server when that is complete.
;;; http://sf.net/projects/eflite
;;; as the tts server.
;;; When and if eflite becomes capable of voice locking,
;;; this file should provide code similar to  outloud-voices.el

;;}}}
;;{{{  Required modules

(require 'cl)
(declaim  (optimize  (safety 0) (speed 3)))
(require 'custom)

;;}}}
;;;###autoload
;;{{{  launch eflite 
;;;###autoload
(defun tts-eflite ()
  "Use eflite TTS server."
  (interactive)
  (let ((dtk-program "eflite"))
    (tts-restart)
    (message "This is Emacspeak! ")))

;;}}}

(provide 'flite-voices)
;;{{{ end of file

;;; local variables:
;;; folded-file: t
;;; byte-compile-dynamic: t
;;; end:

;;}}}

==> emacspeak_29.0.orig.tar.gz: emacspeak-29.0.orig/lisp/flite-voices.el <==
;;; flite.el --- Emacspeak FLite
;;; $Id: flite-voices.el 5798 2008-08-22 17:35:01Z tv.raman.tv $
;;; $Author: tv.raman.tv $
;;; Description:  FLite interface 
;;; Keywords: Emacspeak,  Audio Desktop FLite
;;{{{  LCD Archive entry:

;;; LCD Archive Entry:
;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
;;; A speech interface to Emacs |
;;; $Date: 2008-07-06 10:18:30 -0700 (Sun, 06 Jul 2008) $ |
;;;  $Revision: 4532 $ |
;;; Location undetermined
;;;

;;}}}
;;{{{  Copyright:
;;;Copyright (C) 1995 -- 2007, T. V. Raman 
;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
;;; All Rights Reserved.
;;;
;;; This file is not part of GNU Emacs, but the same permissions apply.
;;;
;;; GNU Emacs is free software; you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 2, or (at your option)
;;; any later version.
;;;
;;; GNU Emacs is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with GNU Emacs; see the file COPYING.  If not, write to
;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

;;}}}
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;{{{  introduction

;;; defines interactive command tts-flite that launches eflite 
;;; this will be updated to use the FLite TCL server when that is complete.
;;; http://sf.net/projects/eflite
;;; as the tts server.
;;; When and if eflite becomes capable of voice locking,
;;; this file should provide code similar to  outloud-voices.el

;;}}}
;;{{{  Required modules

(require 'cl)
(declaim  (optimize  (safety 0) (speed 3)))
(require 'custom)

;;}}}
;;;###autoload
;;{{{  launch eflite 
;;;###autoload
(defun tts-eflite ()
  "Use eflite TTS server."
  (interactive)
  (let ((dtk-program "eflite"))
    (tts-restart)
    (message "This is Emacspeak! ")))

(defun flite-configure-tts ()
  (dectalk-configure-tts)
  (dtk-unicode-update-untouched-charsets '(ascii latin-iso8859-1 eight-bit-graphic)))

;;}}}

(provide 'flite-voices)
;;{{{ end of file

;;; local variables:
;;; folded-file: t
;;; byte-compile-dynamic: t
;;; end:

;;}}}
